@@ -13,7 +13,7 @@ def get_json_serial(packet):
     except Exception as e:
         logging.debug(e)
         return dict()
-    return dict(serial=serial, clientid=clientid, terminal_type="JSON")
+     return dict(terminal_serial=serial, terminal_client_id=clientid, terminal_type="JSON")
 
 
 def get_m7_serial(packet):
